pub struct ResourceAuthorization { /* private fields */ }Expand description
Authorization policy that maps route patterns to allowed roles and permissions.
resource_key→allowed_roles: users with ANY of these roles are granted access.resource_key→required_permissions: users with ANY of these permissions are granted access.
A user is authorized if they have at least one matching role OR at least one matching permission.
Implementations
Sourceimpl ResourceAuthorization
impl ResourceAuthorization