Module server

Module server 

Host builder and hyper server integration.

Includes built-in exception middleware: errors produced by endpoints are caught and converted to well-formed HTTP error responses using Error::status_code().

Structs

Host
HostAppBuilder
HostBuilder
Server
A fully built server that owns its runtime lifecycle.
ServerHandle
Handle for a running server, allowing programmatic graceful shutdown.